====================
Abbreviations
====================


**API**: Application programming interface

**EPA**: Environmental Protection Agency

**IDE**: Integrated development environment

**SI**: International System of Units

**US**: United States

**MOC**: Method of Characteristics

**TSNET**: Transient Simulation in water Networks
